@@ -14,7 +14,7 @@
 # Author: Dominique Pelle <dominique.pelle@gmail.com>
 #
 
-INPUT=lexique-dicollecte-fr-v5.5
+INPUT=lexique-dicollecte-fr-v5.7
 
 if [ ! -f $INPUT.txt ]; then
   wget http://www.dicollecte.org/download/fr/$INPUT.zip
@@ -36,8 +36,10 @@ java -jar morfologik-stemming-nodict-1.4.0.jar fsa_build \
 # convenient (it would be better to indicate the location of output files).
 rm -f /tmp/SynthDictionaryBuilder*.txt_tags.txt
 rm -f /tmp/DictionaryBuilder*.dict
-java -cp ../../../../../../../../../languagetool-standalone/target/LanguageTool-3.2-SNAPSHOT/LanguageTool-3.2-SNAPSHOT/languagetool.jar \
-     org.languagetool.dev.SynthDictionaryBuilder \
-     $INPUT.txt.LT.txt french_synth.info
-cp /tmp/SynthDictionaryBuilder*.txt_tags.txt french_tags.txt
-cp /tmp/DictionaryBuilder*.dict              french_synth.dict
+
+java -cp ../../../../../../../../../languagetool-tools/target/languagetool-tools-3.6-SNAPSHOT-jar-with-dependencies.jar \
+     org.languagetool.tools.SynthDictionaryBuilder \
+     -i $INPUT.txt.LT.txt \
+     -info french_synth.info \
+     -o french_synth.dict
+mv -f /tmp/SynthDictionaryBuilder*.txt_tags.txt french_tags.txt
